==> operation-labels-1.0.0-20140312.223145-10-sources.jar: org/gcube/data/analysis/tabulardata/operation/labels/AddColumnNameFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.labels;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.model.metadata.common.LocalizedText;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.ColumnTransformationWorkerFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.LocalizedTextParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

@Singleton
public class AddColumnNameFactory extends ColumnTransformationWorkerFactory {

	private static final OperationId OPERATION_ID = new OperationId(1006);
	
	CubeManager cubeManager;
	
	private static List<Parameter> parameters = new ArrayList<Parameter>();

	public static LocalizedTextParameter NAME_LABEL_PARAMETER = new LocalizedTextParameter("NAME_PARAMETER_ID",
			"Column name", "The column name to set", Cardinality.ONE);

	
	
	static {
		parameters.add(NAME_LABEL_PARAMETER);
	}
	
	
	@Inject
	public AddColumnNameFactory(CubeManager cubeManager) {		
		this.cubeManager = cubeManager;
	}


	@Override
	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation);		
		return new AddColumnName(cubeManager, invocation);
	}

	@Override
	protected String getOperationName() {
		return "Add column name";
	}

	@Override
	protected String getOperationDescription() {
		return "Add a name label to a column";
	}


	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}
}

==> operation-labels-1.0.1-20140404.135126-1-sources.jar: org/gcube/data/analysis/tabulardata/operation/labels/AddColumnNameFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.labels;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.ColumnTransformationWorkerFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.LocalizedTextParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

@Singleton
public class AddColumnNameFactory extends ColumnTransformationWorkerFactory {

	private static final OperationId OPERATION_ID = new OperationId(1006);
	
	CubeManager cubeManager;
	
	private static List<Parameter> parameters = new ArrayList<Parameter>();

	public static LocalizedTextParameter NAME_LABEL_PARAMETER = new LocalizedTextParameter("NAME_PARAMETER_ID",
			"Column name", "The column name to set", Cardinality.ONE);

	
	
	static {
		parameters.add(NAME_LABEL_PARAMETER);
	}
	
	
	@Inject
	public AddColumnNameFactory(CubeManager cubeManager) {		
		this.cubeManager = cubeManager;
	}


	@Override
	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation,cubeManager);		
		return new AddColumnName(cubeManager, invocation);
	}

	@Override
	protected String getOperationName() {
		return "Add column name";
	}

	@Override
	protected String getOperationDescription() {
		return "Add a name label to a column";
	}


	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}
}
